const initialState = {
    invoices: [],
    filterPaymentsInvoice: [],
    currencyInvoice: [],
    selectedInvoice : null
}

const state = {
    invoices: initialState.invoices,
    currencyInvoice: initialState.currencyInvoice,
    selectedInvoice: initialState.selectedInvoice,
    filterPaymentsInvoice: initialState.filterPaymentsInvoice
}

const getters = {
    /**
     * [invoices description]
     */
    invoices(state) {
        return state.invoices
    },
    /**
     * [currencyInvoice description]
     */
    currencyInvoice(state) {
        return state.currencyInvoice
    },
    /**
     * [selectedInvoice description]
     */
    selectedInvoice(state) {
        return state.selectedInvoice
    },
    /**
     * [invoicesVisible]
     */
    invoicesVisible(state) {
        return state.filterPaymentsInvoice.length === 0 ?state.invoices : state.filterPaymentsInvoice
    }
}

const mutations = {
    /**
     * [invoices description]
     */
    setInvoices (state, payload) {
        state.invoices = payload
    },
    /**
     * [selectedInvoice description]
     */
    setSelectedInvoice (state, payload) {
        state.selectedInvoice = payload
    },
    /**
     * [currencyInvoice description]
     */
    setSelectedCurrencyInvoice (state, payload) {
        state.currencyInvoice = payload
    },
    /**
     * [moveLines description]
     */
    setMoveInInvoice (state, payload) {
        if (payload.mode === 'full') {
            payload.moveLine.forEach(moves => {
                let movesFound = state.selectedInvoice.moveLines.find(item => item.id === moves.id)

                if (movesFound) return

                state.selectedInvoice.moveLines = [moves, ...state.selectedInvoice.moveLines]
            })
        } else {

            let movesFound = state.selectedInvoice.moveLines.find(item => item.id === payload.moveLine.id)
            if (movesFound) return
            state.selectedInvoice.moveLines = [payload.moveLine, ...state.selectedInvoice.moveLines]
        }
    },
    /**
     * [filterPaymentsInvoice description]
     */
    setFilterPaymentsInvoice (state, payload) {
        return state.filterPaymentsInvoice = payload
    }
}

const actions = {
    /**
     * [Selecciona las factura del cliente seleccionado]
     */
    selectCustomerInvoices ({ commit }, payload) {
        commit('setInvoices', payload)
    },
    /**
     * [Seleccionar una factura]
     */
    selectInvoice ({ commit, dispatch }, payload) {
        commit('setSelectedInvoice', payload)
        commit('setSelectedCurrencyInvoice', payload.currency)
        dispatch('selectMoveInvoice', payload.moveLines)
    },
    /**
     *[ADD_MOVE_IN_INVOICE]
     */
    addMoveInInvoice ({ commit }, payload) {
        commit('setMoveInInvoice', payload)
    },
    /**
     *[FILTER_PAYMENTS_INVOICE]
     */
    filterPaymentsInvoice ({ commit }, payload ){
        commit('setFilterPaymentsInvoice', payload)
    },
    /**
     * [RESET_INVOICES]
     */
    resetInvoices ({ commit }) {
        commit('setInvoices', [] )
        commit('setSelectedInvoice', null)
        commit('setSelectedCurrencyInvoice', [] )
        commit('setFilterPaymentsInvoice', [] )
    }
 }

export default {
    state,
    getters,
    mutations,
    actions
}
