const initialState = {
    moves : null,
    selectedMoveLine: null,
    movesPayments: [],
    movesPaymentsTotal: 0,
}

const state = {
    moves: initialState.moves,
    selectedMoveLine: initialState.selectedMoveLine,
    movesPayments: initialState.movesPayments,
    movesPaymentsTotal: initialState.movesPaymentsTotal,
}

const getters = {
    /**
     * [moves description]
     */
    moves (state) {
        return state.moves
    },
    /**
     * [selectedMoveLine description]
     */
    selectedMoveLine (state){
        return state.selectedMoveLine
    },
    /**
     * [movesPayments description]
     */
    movesPayments (state) {
        return state.movesPayments
    },
    /**
     * [movesPaymentsTotal description]
     */
    movesPaymentsTotal (state) {
        return state.movesPaymentsTotal
    }
}

const mutations = {
    /**
     * [moves description]
     */
    setMoves (state, payload) {
        state.moves =  payload
    },
    /**
     * [movesPayments description]
     */
    setMovePayments (state, payload) {
        state.movesPayments = payload
    },
    /**
     * [selectedMoveLine description]
     */
    setSelectedMoveLine (state, payload) {
        state.selectedMoveLine = payload
    },
    /**
     * [movesPayments description]
     */
    setSelectedMovePayments (state, payload) {
        state.movesPayments = [payload, ...state.movesPayments]
    },
    /**
     * [actions description]
     */
    removeMoveLine (state, payload) {
        let moveFoundIndex = state.moves.findIndex(item => item.id === payload.id)
        state.moves.splice(moveFoundIndex, 1)
    },
    /**
     * [actions description]
     */
    removePaymentsMove ( state, payload) {
        if (payload.mode ==='full') {
            payload.moveLine.forEach(moves => {
                let movesFoundIndex = state.moves.find(item => item.id === moves.id)
                if (movesFoundIndex) return
                /*ADD MOVE LINE*/
                state.moves = [moves, ...state.moves]
                /* REMOVE MOVE CARD*/
                let movesPaymentsFoundIndex = state.movesPayments.findIndex(item => item.id === moves.id)
                state.movesPayments.splice(movesPaymentsFoundIndex, 1)
            })
        } else {
            let movesFound = state.moves.find(item => item.id === payload.moveLine.id)
            if (movesFound) return
            state.moves = [payload.moveLine, ...state.moves]

            let movesFoundIndex = state.movesPayments.findIndex(item => item.id === payload.moveLine.id)
            state.movesPayments.splice(movesFoundIndex, 1)
        }
    },
    /**
     * [total description]
     */
    setTotalMovePayments (state) {
        let total = 0

        state.movesPayments.forEach(item => {
            total = total + item.amountResidualCurrency
        })

        state.movesPaymentsTotal = total
    },
    /**
     * [actions description]
     */
    setOrderMoveLine (state) {
        state.moves =  state.moves.sort((a, b) => {
            return a.dateMaturity > b.dateMaturity
        })
    },
    /**
     * [actions description]
     */
    setOrderPaymentsMove (state) {
        state.movesPayments = state.movesPayments.sort((a, b) => {
            return a.dateMaturity > b.dateMaturity
        })
    }
}

const actions = {
    /**
     * [SELECT_MOVE_INVOICE]
     */
    selectMoveInvoice ({ commit }, payload) {
        commit('setMoves', payload)
        commit('setOrderMoveLine')
    },
    /**
     * [SELECT_MOVE]
     */
    selectMove ({ commit, dispatch }, payload) {
        commit('setSelectedMovePayments', payload)
        commit('setSelectedMoveLine', payload)
        /* Remover Move Line */
        commit('removeMoveLine', payload)
        commit('setTotalMovePayments')
        commit('setOrderPaymentsMove')

        dispatch('initCurrenciesAmount')
    },
    /**
     *[REMOVE_MOVE_PAYMENTS]
     */
    removeMovePayments ({ commit, dispatch }, payload) {
        dispatch('ADD_MOVE_IN_INVOICE', {
            moveLine: payload,
            mode: 'partial'
        })
        commit('removePaymentsMove', {
            moveLine: payload,
            mode: 'partial'
        })
        commit('setOrderMoveLine')
        commit('setTotalMovePayments')
        dispatch('initCurrenciesAmount')
    },
    /**
     * [REMOVE_MOVE_PAYMENTS_ALL]
     */
    removeMovePaymentsAll ({commit, dispatch, getters}) {
        dispatch('addMoveInInvoice',{
            moveLine: getters.movesPayments.map(item => {
                return item
            }),
            mode: 'full'
        })
        commit('removePaymentsMove' , {
            moveLine: getters.movesPayments.map(item => {
                return item
            }),
            mode: 'full'
        })
        dispatch('resetSelectedJournal')
        commit('setOrderMoveLine')
        commit('setTotalMovePayments')
    },
    /**
     * [RESET_MOVE_LINES]
     */
    resetMoveLines ({ commit }) {
        commit('setMoves', [] )
        commit('setSelectedMoveLine', null )
        commit('setMovePayments', [] )
        commit('setTotalMovePayments')
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}
