const initialState = {
    paidTotal: 0,
    paymentsReturned: 0,
    paymentCurrencyTotal: 0,
    selectedPaymentsBank: null,
    selectedPaymentsBankType: null,
    paymentsBankRef: '',
    paymentsBankDateMaturity: '',
    paymentsBankAmount: 0,
    recidualAMountReceipt: 0,
    paymentsBankNumberCta: '',
    paymentsBankNameHolder: '',
    showBankPaymentModal: false
}

const state = {
    paidTotal: initialState.paidTotal,
    paymentsReturned: initialState.paymentsReturned,
    paymentCurrencyTotal: initialState.paymentCurrencyTotal,
    selectedPaymentsBank: initialState.selectedPaymentsBank,
    selectedPaymentsBankType: initialState.selectedPaymentsBankType,
    paymentsBankRef: initialState.paymentsBankRef,
    paymentsBankDateMaturity: initialState.paymentsBankDateMaturity,
    paymentsBankNumberCta: initialState.paymentsBankNumberCta,
    paymentsBankNameHolder: initialState.paymentsBankNameHolder,
    paymentsBankAmount: initialState.paymentsBankAmount,
    showBankPaymentModal: initialState.showBankPaymentModal,
    recidualAMountReceipt: initialState.recidualAMountReceipt
}

const getters = {
    /**
     * [paidTotal description]
     */
    paidTotal (state) {
        return state.paidTotal
    },
    /**
     * [paymentsReturned description]
     */
    paymentsReturned (state) {
        return state.paymentsReturned
    },
    /**
     * [paymentCurrencyTotal description]
     */
    paymentCurrencyTotal (state) {
        return state.paymentCurrencyTotal
    },
    /**
     * [selectedPaymentsBank description]
     */
    selectedPaymentsBank(state) {
        return state.selectedPaymentsBank
    },
    /**
     * [selectedPaymentsBankType description]
     */
    selectedPaymentsBankType(state) {
        return state.selectedPaymentsBankType
    },
    /**
     * [paymentsBankRef description]
     */
    paymentsBankRef (state) {
        return state.paymentsBankRef
    },
    /**
     * [paymentsBankDateMaturity description]
     */
    paymentsBankDateMaturity (state) {
        return state.paymentsBankDateMaturity
    },
    /**
     * [paymentsBankNumberCta description]
     */
    paymentsBankNumberCta ( state ) {
        return state.paymentsBankNumberCta
    },
    /**
     * [paymentsBankNameHolder description]
     */
    paymentsBankNameHolder( state ) {
        return state.paymentsBankNameHolder
    },
    /**
     * [showBankPaymentModal description]
     */
    showBankPaymentModal( state ) {
        return state.showBankPaymentModal
    },
    /**
     * [paymentsBankAmount description]
     */
    paymentsBankAmount(state) {
        return state.paymentsBankAmount
    },
    /**
     * [recidualAMountReceipt description]
     */
    recidualAMountReceipt(state){
        return state.recidualAMountReceipt
    }
}

const mutations = {
    /**
     * [paidTotal description]
     */
    setPaidTotal (state, payload) {
        state.paidTotal = payload
    },
    /**
     * [paymentCurrencyTotal description]
     */
    setCurrencyTotal (state, payload) {
        state.paymentCurrencyTotal = payload
    },
    /**
     * [SET_CALCULATE_CURRENCY_TOTAL]
     */
    setCalculateCurrencyTotal (state, payload) {
        let currencyJournal = payload.movesCurrencyAmount.find(item => item.id ===payload.currency.id)
        let total = currencyJournal.amount
        if (!currencyJournal)
            total = 0
        state.paymentCurrencyTotal = total
    },
    /**
     * [selectedPaymentsBank description]
     */
    setselectedBank (state, payload) {
        state.selectedPaymentsBank = payload
    },
    /**
     * [selectedPaymentsBankType description]
     */
    setSelectedBankType (state, payload) {
        state.selectedPaymentsBankType = payload
    },
    /**
     * [paymentsBankRef description]
     */
    setPaymentsBankRef (state, payload) {
        state.paymentsBankRef = payload
    },
    /**
     * [paymentsBankDateMaturity description]
     */
    setPaymentsBankDateMaturity (state, payload) {
        state.paymentsBankDateMaturity = payload
    },
    /**
     * [paymentsBankNumberCta description]
     */
    setPaymentsBankNumberCta (state, payload) {
        state.paymentsBankNumberCta =  payload
    },
    /**
     * [actions description]
     */
    setPaymentsBankNameHolder (state, payload) {
        state.paymentsBankNameHolder = payload
    },
    /**
     * [actions description]
     */
    setShowBankPaymentModal (state, payload) {
        state.showBankPaymentModal = payload
    },
    /**
     * [actions description]
     */
    setPaymentsBankAmount (state, payload) {
        state.paymentsBankAmount = payload
    },
    /**
     * [recidualAMountReceipt description]
     */
    setRecidualAmountReceipt ( state, payload ) {
        state.recidualAMountReceipt = payload
    }
}

const actions = {
    /**
     * [CHANGE_INITIAL_PAID]
     */
    changeInitialPaid ({ commit, getters, dispatch },payload) {
        let bank = !!getters.bank.length && !!getters.bankType.length && !!getters.selectedJournal && getters.selectedJournal.type === 'bank' && payload > getters.recidualAMountReceipt
        if (!!bank){
            dispatch('paymentsNotify','El monto de entrega no puede superar el saldo del cheque (valor disponible '+getters.recidualAMountReceipt+')')
            return
        }
        commit('setPaidTotal', payload)
    },
    /**
     * [CALCULATE_CURRENCY_TOTAL]
     */
    calculateCurrencyTotal ({commit, getters}, payload) {
        let currency = []
        if (payload.currency.id){
            currency = payload.currency
        } else {
            currency = getters.currencyCompany
        }
        commit('setCalculateCurrencyTotal', {
            currency: currency,
            movesCurrencyAmount: getters.currencyAmount
        })
        commit('setPaidTotal', 0)

        if (payload.type === 'bank') {
            commit('setShowBankPaymentModal', !!getters.bank.length && !!getters.bankType.length)
        }
    },
    /**
     * [amount description]
     */
    submitBankPayments ( { commit, dispatch, getters }, payload){
        if (!payload.bank){
            dispatch('resetPaymentsBank')
            return
        }
        if (payload.amountReceipt <= 0 ){
            dispatch('paymentsNotify','Cheque sin saldo')
            dispatch('resetPaymentsBank')
            return
        }

        commit('setselectedBank', payload.bank)
        commit('setSelectedBankType', payload.bankType)
        commit('setPaymentsBankRef', payload.number)
        commit('setPaymentsBankDateMaturity', payload.dateMaturity)
        commit('setPaymentsBankNumberCta', payload.numberCta)
        commit('setPaymentsBankNameHolder', payload.nameHolder)
        commit('setPaymentsBankAmount', payload.amountTotal)
        commit('setRecidualAmountReceipt', payload.amountReceipt)
        commit('setShowBankPaymentModal', false)

        let amount = payload.amountReceipt

        if (amount > getters.paymentCurrencyTotal)
            amount = getters.paymentCurrencyTotal

        commit('setPaidTotal', amount)
    },
    /**
     * [RESET_PAYMENTS_BANK]
     */
    resetPaymentsBank ({commit, dispatch}) {
        commit('setselectedBank', null)
        commit('setSelectedBankType', null)
        commit('setPaymentsBankRef', '')
        commit('setPaymentsBankDateMaturity', '')
        commit('setPaymentsBankNumberCta', '')
        commit('setPaymentsBankNameHolder', '')
        commit('setPaymentsBankAmount', 0)
        commit('setRecidualAmountReceipt', 0)

        commit('setPaidTotal', 0)
        commit('setCurrencyTotal', 0)

        dispatch('resetSelectedJournal')

        commit('setShowBankPaymentModal', false)
    },
    /**
     * [RESET_PAYMENTS]
     */
    resetPayments ({ commit }) {
        commit('setPaidTotal', 0)
        commit('setCurrencyTotal', 0)
        commit('setselectedBank', null)
        commit('setSelectedBankType', null)
        commit('setPaymentsBankRef', '')
        commit('setPaymentsBankDateMaturity', '')
        commit('setPaymentsBankNumberCta', '')
        commit('setPaymentsBankNameHolder', '')

        commit('setShowBankPaymentModal', false)
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}
